==> rice-impex-master-2.1.15-sql.jar: sql/mysql/KRCR_CMPNT_T.sql <==
TRUNCATE TABLE KRCR_CMPNT_T
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','ActionList','Action List','KR-WKFLW','1821D8BAB21E498F9FB1ECCA25C37F9B',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','All','All','KR-IDM','69A9BABE4A0BBD56E0404F8189D82B0F',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','All','All','KR-NS','53680C68F596AD9BE0404F8189D80A6C',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','All','All','KR-WKFLW','705611FB54134417E0404F8189D8453B',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','Backdoor','Backdoor','KR-WKFLW','F7E44233C2C440FFB1A399548951160A',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','Batch','Batch','KR-IDM','69A9BABE4A0CBD56E0404F8189D82B0F',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','Batch','Batch','KR-NS','53680C68F597AD9BE0404F8189D80A6C',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','Document','Document','KR-IDM','69A9BABE4A0DBD56E0404F8189D82B0F',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','Document','Document','KR-NS','53680C68F598AD9BE0404F8189D80A6C',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','DocumentSearch','Document Search','KR-WKFLW','B0255911E83C4FF3E0404F8189D86E3E',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','EDocLite','eDocLite','KR-WKFLW','51DD5B9FACDD4EDAA9CA8D53A82FCCCA',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','Feature','Feature','KR-WKFLW','BBD9976498A4441F904013004F3D70B3',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','GlobalReviewer','Global Reviewer','KR-WKFLW','C21B0C6229144F6FBC52A10A38E51E3B',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','Lookup','Lookup','KR-IDM','69A9BABE4A0EBD56E0404F8189D82B0F',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','Lookup','Lookup','KR-NS','53680C68F599AD9BE0404F8189D80A6C',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','Mailer','Mailer','KR-WKFLW','5DB9D1433E214325BE380C82762A223B',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','Note','Note','KR-WKFLW','868D39EC269B4402B3136C74C2342F22',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','Notification','Notification','KR-WKFLW','D04AFB1812E34723ABEB64986AC61DC9',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','PurgePendingAttachmentsStep','Purge Pending Attachments Step','KR-IDM','69A9BABE4A0FBD56E0404F8189D82B0F',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','PurgePendingAttachmentsStep','Purge Pending Attachments Step','KR-NS','5A689075D3577AEBE0404F8189D80321',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','PurgeSessionDocumentsStep','Purge Session Documents Step','KR-IDM','69A9BABE4A10BD56E0404F8189D82B0F',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','PurgeSessionDocumentsStep','Purge Session Documents Step','KR-NS','5A689075D3567AEBE0404F8189D80321',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','QuickLinks','Quick Link','KR-WKFLW','3E26DA76458A46D68CBAF209DA036157',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','Route','Routing','KR-WKFLW','583C2D3562D44DBAA5FEA998EB601DC9',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','RouteQueue','Route Queue','KR-WKFLW','D4F6DDEF69B24265AA2A170A62A1CADB',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','Rule','Rule','KR-WKFLW','B0360A1EA62D3636E0404F8189D8579F',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','ScheduleStep','Schedule Step','KR-IDM','69A9BABE4A11BD56E0404F8189D82B0F',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','ScheduleStep','Schedule Step','KR-NS','5A689075D3587AEBE0404F8189D80321',1)
/

==> rice-impex-master-2.5.9-sql.jar: sql/mysql/KRCR_CMPNT_T.sql <==
TRUNCATE TABLE KRCR_CMPNT_T
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','ActionList','Action List','KR-WKFLW','1821D8BAB21E498F9FB1ECCA25C37F9B',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','All','All','KR-IDM','69A9BABE4A0BBD56E0404F8189D82B0F',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','All','All','KR-NS','53680C68F596AD9BE0404F8189D80A6C',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','All','All','KR-WKFLW','705611FB54134417E0404F8189D8453B',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','Backdoor','Backdoor','KR-WKFLW','F7E44233C2C440FFB1A399548951160A',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','Batch','Batch','KR-IDM','69A9BABE4A0CBD56E0404F8189D82B0F',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','Batch','Batch','KR-NS','53680C68F597AD9BE0404F8189D80A6C',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','Document','Document','KR-IDM','69A9BABE4A0DBD56E0404F8189D82B0F',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','Document','Document','KR-NS','53680C68F598AD9BE0404F8189D80A6C',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','DocumentSearch','Document Search','KR-WKFLW','B0255911E83C4FF3E0404F8189D86E3E',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','EDocLite','eDocLite','KR-WKFLW','51DD5B9FACDD4EDAA9CA8D53A82FCCCA',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','Feature','Feature','KR-WKFLW','BBD9976498A4441F904013004F3D70B3',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','GlobalReviewer','Global Reviewer','KR-WKFLW','C21B0C6229144F6FBC52A10A38E51E3B',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','Lookup','Lookup','KR-IDM','69A9BABE4A0EBD56E0404F8189D82B0F',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','Lookup','Lookup','KR-KRAD','E40693F368DCC301E0406E0AC31D7203',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','Lookup','Lookup','KR-NS','53680C68F599AD9BE0404F8189D80A6C',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','Mailer','Mailer','KR-WKFLW','5DB9D1433E214325BE380C82762A223B',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','Note','Note','KR-WKFLW','868D39EC269B4402B3136C74C2342F22',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','Notification','Notification','KR-WKFLW','D04AFB1812E34723ABEB64986AC61DC9',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','PurgePendingAttachmentsStep','Purge Pending Attachments Step','KR-IDM','69A9BABE4A0FBD56E0404F8189D82B0F',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','PurgePendingAttachmentsStep','Purge Pending Attachments Step','KR-NS','5A689075D3577AEBE0404F8189D80321',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','PurgeSessionDocumentsStep','Purge Session Documents Step','KR-IDM','69A9BABE4A10BD56E0404F8189D82B0F',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','PurgeSessionDocumentsStep','Purge Session Documents Step','KR-NS','5A689075D3567AEBE0404F8189D80321',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','QuickLinks','Quick Link','KR-WKFLW','3E26DA76458A46D68CBAF209DA036157',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','Route','Routing','KR-WKFLW','583C2D3562D44DBAA5FEA998EB601DC9',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','RouteQueue','Route Queue','KR-WKFLW','D4F6DDEF69B24265AA2A170A62A1CADB',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','Rule','Rule','KR-WKFLW','B0360A1EA62D3636E0404F8189D8579F',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','ScheduleStep','Schedule Step','KR-IDM','69A9BABE4A11BD56E0404F8189D82B0F',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','ScheduleStep','Schedule Step','KR-NS','5A689075D3587AEBE0404F8189D80321',1)
/
INSERT INTO KRCR_CMPNT_T (ACTV_IND,CMPNT_CD,NM,NMSPC_CD,OBJ_ID,VER_NBR)
  VALUES ('Y','TestComponent','Test Component','KR-SAP','69A9BABE4A0FBD56E0404F8189D82512',1)
/
